@@ -1,12 +1,12 @@
 from aiohttp import web as aio_web
 
-from bolinette import blnt, types
+from bolinette import web
 from bolinette.decorators import controller, get
 from bolinette.defaults.services import FileService
 
 
-@controller('file', '/file')
-class FileController(blnt.Controller):
+@controller('file', '/file', middlewares=['auth'])
+class FileController(web.Controller):
     @property
     def file_service(self) -> FileService:
         return self.context.service('file')
@@ -16,8 +16,7 @@ class FileController(blnt.Controller):
             self.defaults.get_one(key='key')
         ]
 
-    @get('/{key}/download',
-         access=types.web.AccessToken.Fresh)
+    @get('/{key}/download')
     async def download_file(self, match):
         file = await self.service.get_first_by('key', match['key'])
         headers = {
